@@ -2,10 +2,11 @@ from __future__ import annotations
 from tollbit.tokens import TollbitToken
 from tollbit._apis.content_api import ContentAPI
 from tollbit._apis.token_api import TokenAPI
+from tollbit._apis.content_retrieval_api import ContentRetrievalAPI
 from urllib.parse import urlparse
 from tollbit._apis.models import (
     CreateCrawlAccessTokenRequest,
-    DeveloperContentCatalogResponse,
+    CatalogResponse,
     GetContentResponse,
 )
 from tollbit.content_formats import Format
@@ -34,27 +35,34 @@ def create_client(
             user_agent=user_agent,
             env=env,
         ),
+        content_retrieval_api=ContentRetrievalAPI(
+            user_agent=user_agent,
+            env=env,
+        ),
     )
 
 
 class CrawlContentClient:
     content_api: ContentAPI
     token_api: TokenAPI
+    content_retrieval_api: ContentRetrievalAPI
 
     def __init__(
         self,
         content_api: ContentAPI,
         token_api: TokenAPI,
+        content_retrieval_api: ContentRetrievalAPI,
     ):
         self.content_api = content_api
         self.token_api = token_api
+        self.content_retrieval_api = content_retrieval_api
 
     def list_content_catalog(
         self,
         url: str,
         page_size: int = 100,
         page_token: str | None = None,
-    ) -> DeveloperContentCatalogResponse | None:
+    ) -> CatalogResponse | None:
         parsed_url = parse_url_with_forgiveness(url)
         logger.debug(
             f"Fetching content catalog {parsed_url.netloc}",
@@ -66,10 +74,10 @@ class CrawlContentClient:
             page_token=page_token,
         )
 
-        if len(results) == 0:
+        if len(results.pages) == 0:
             return None
 
-        return results[0]
+        return results
 
     def crawl_content(
         self,
@@ -87,7 +95,7 @@ class CrawlContentClient:
         token_resp = self.token_api.get_crawl_token(req)
         token: TollbitToken = TollbitToken(token_resp.token)
 
-        response = self.content_api.get_content(
+        response = self.content_retrieval_api.get_content(
             content_url=f"{parsed_url.netloc}{parsed_url.path}", token=token, format=format
         )
 
